# Configuration file for the Sphinx documentation builder.
#
# This file only contains a selection of the most common options. For a full
# list see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

# -- Path setup --------------------------------------------------------------

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#
import os
import sys

# Make the modules importable
sys.path.insert(0, os.path.abspath(".."))
sys.path.insert(0, os.path.abspath("../basta"))
sys.path.insert(0, os.path.abspath("../examples"))

# Add required environment variable
if not "BASTADIR" in os.environ:
    os.environ["BASTADIR"] = os.path.abspath("../basta")


# -- Project information -----------------------------------------------------

# General information about the project.
project = "BASTA"
copyright = "2022, The BASTA Team"
author = "The BASTA Team"

# The short X.Y version.
version = "1.2.0"

# The full version, including alpha/beta/rc tags.
release = "1.2.0"


# -- General configuration ------------------------------------------------

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = [
    "sphinx.ext.autodoc",
    "sphinx.ext.todo",
    "sphinx.ext.mathjax",
    "sphinx.ext.viewcode",
    "sphinx.ext.napoleon",
]

# Napoleon (docstring reading) settings
napoleon_google_docstring = False
napoleon_use_param = False
napoleon_use_rtype = False

# Add any paths that contain templates here, relative to this directory.
templates_path = ["_templates"]

# The suffix(es) of source filenames.
# You can specify multiple suffix as a list of string:
#
source_suffix = ".rst"

# The master toctree document.
master_doc = "index"

# The language for content autogenerated by Sphinx. Refer to documentation
# for a list of supported languages.
#
# This is also used if you do content translation via gettext catalogs.
# Usually you set "language" from the command line for these cases.
language = None

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This patterns also effect to html_static_path and html_extra_path
exclude_patterns = ["_build", "Thumbs.db", ".DS_Store"]

# The name of the Pygments (syntax highlighting) style to use.
pygments_style = "sphinx"

# If true, `todo` and `todoList` produce output, else they produce nothing.
todo_include_todos = False

# Example configuration for intersphinx: refer to the Python standard library.
intersphinx_mapping = {"https://docs.python.org/3/": None}

# This value contains a list of modules to be mocked up. This is useful when some
# external dependencies are not met at build time and break the building process.
# You may only specify the root package of the dependencies themselves and omit
# the sub-modules:
autodoc_mock_imports = [
    "astropy",
    "bottleneck",
    "dustmaps",
    "h5py",
    "healpy",
    "matplotlib",
    "scikit-learn",
    "sklearn",
    "scipy",
    "tqdm",
]


# -- Options for HTML output ----------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
html_theme = "sphinx_rtd_theme"

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ["_static"]

# Logo
html_logo = "basta_crop_low-res.png"
html_theme_options = {
    "logo_only": True,
}


# -- Options for HTMLHelp output ------------------------------------------

# Output file base name for HTML help builder.
htmlhelp_basename = "BASTAdoc"
